@@ -8,7 +8,7 @@ CSC <- function (formula,data,cause,survtype="hazard",...){
   responseFormula <- reformulate("1", formula[[1]][[2]])
   # }}}
   # {{{ response
-  require(survival)
+  ## require(survival)
   call <- match.call()
   # get information from formula
   mf <- model.frame(responseFormula, data = data, na.action = na.omit)
@@ -63,7 +63,8 @@ CSC <- function (formula,data,cause,survtype="hazard",...){
       fit$call$formula <- fit$formula
       fit
     })
-    names(CoxModels) <- paste("Cause",causes)
+    ## names(CoxModels) <- paste("Cause",causes)
+    names(CoxModels) <- paste("Cause",c(theCause,otherCauses))
   }
   else{
     CoxModels <- lapply(1:2,function(x){
